@@ -1,4 +1,4 @@
-indexes <- c("oni", "ao", "nao", "soi", "mei", "npgo", "aao")
+indexes <- c("oni", "ao", "nao", "soi", "mei", "npgo", "aao", "pdo")
 
 context("Testing download")
 
@@ -8,7 +8,7 @@ test_download <- function(index) {
   fun <- match.fun(function_name)
   
   test_that(paste0("Does ", function_name, " download a data.frame?"), {
-    skip_if_no_internet()
+    skip_if_offline()
     skip_if_shutdown()
     expect_is( fun(), "data.frame" )
   })
@@ -28,7 +28,7 @@ test_read <- function(index) {
     # read_fun <- match.fun(paste0("read_", index))
     read_fun <- get(paste0("read_", index), asNamespace("rsoi"), mode = "function")
     
-    skip_if_no_internet()
+    skip_if_offline()
     skip_if_shutdown()
     
     data <- download_fun(use_cache = FALSE, file = file)
